@@ -2,9 +2,7 @@
 
 """Package entry point."""
 
-
-from stlearn.app import main
-
+from stlearn.app import cli
 
 if __name__ == "__main__":  # pragma: no cover
-    main()
+    cli.main()
