@@ -1,10 +1,22 @@
-from .adds.add_image import image
-from .adds.add_positions import positions
-from .adds.parsing import parsing
-from .adds.add_lr import lr
-from .adds.annotation import annotation
-from .adds.add_labels import labels
 from .adds.add_deconvolution import add_deconvolution
-from .adds.add_mask import add_mask
-from .adds.add_mask import apply_mask
+from .adds.add_image import image
+from .adds.add_labels import labels
 from .adds.add_loupe_clusters import add_loupe_clusters
+from .adds.add_lr import lr
+from .adds.add_mask import add_mask, apply_mask
+from .adds.add_positions import positions
+from .adds.annotation import annotation
+from .adds.parsing import parsing
+
+__all__ = [
+    "image",
+    "positions",
+    "parsing",
+    "lr",
+    "annotation",
+    "labels",
+    "add_deconvolution",
+    "add_mask",
+    "apply_mask",
+    "add_loupe_clusters",
+]
