@@ -1,32 +1,35 @@
-from typing import Optional, Union
-from anndata import AnnData
-from pathlib import Path
-import os
 import pandas as pd
+from anndata import AnnData
 
 
 def lr(
     adata: AnnData,
-    db_filepath: str = None,
+    db_filepath: str,
     sep: str = "\t",
     source: str = "connectomedb",
     copy: bool = False,
-) -> Optional[AnnData]:
+) -> AnnData | None:
     """Add significant Ligand-Receptor pairs into AnnData object
 
     Parameters
     ----------
-    adata: AnnData          The data object to add L-R info into
-    db_filepath: str      The path to the CPDB results file
-    sep: str                Separator of the CPDB results file
-    source: str             Source of LR database (default: connectomedb, can also support 'cellphonedb')
-    copy: bool              Copy flag indicating copy or direct edit
+    adata: AnnData
+        The data object to add L-R info into
+    db_filepath: str
+        The path to the CPDB results file
+    sep: str
+        Separator of the CPDB results file
+    source: str
+        Source of LR database (default: connectomedb, can also support 'cellphonedb')
+    copy: bool
+        Copy flag indicating copy or direct edit
 
     Returns
     -------
     adata: AnnData          The data object that L-R added into
 
     """
+    adata = adata.copy() if copy else adata
 
     if source == "cellphonedb":
         cpdb = pd.read_csv(db_filepath, sep=sep)
