@@ -1,17 +1,12 @@
-from typing import Optional, Union
 from anndata import AnnData
-from matplotlib import pyplot as plt
-from pathlib import Path
-import os
 
 
 def annotation(
     adata: AnnData,
-    label_list: list,
+    label_list: list[str],
     use_label: str = "louvain",
     copy: bool = False,
-) -> Optional[AnnData]:
-
+) -> AnnData | None:
     """\
     Adding annotation for cluster
 
@@ -31,15 +26,17 @@ def annotation(
     **[cluster method name]_anno** : `adata.obs` field
         The annotation of cluster results.
     """
-
     if label_list is None:
         raise ValueError("Please give the label list!")
 
+    adata = adata.copy() if copy else adata
+
     if len(label_list) != len(adata.obs[use_label].unique()):
         raise ValueError("Please give the correct number of label list!")
 
-    adata.obs[use_label + "_anno"] = adata.obs[use_label]
-    adata.obs[use_label + "_anno"].cat.categories = label_list
+    adata.obs[use_label + "_anno"] = adata.obs[use_label].cat.rename_categories(
+        label_list
+    )
 
     print("The annotation is added to adata.obs['" + use_label + "_anno" + "']")
 
