@@ -1,9 +1,6 @@
-from typing import Optional, Union
-import numpy as np
-from anndata import AnnData
-from numpy.random.mtrand import RandomState
-from scipy.sparse import issparse
 import scanpy
+from anndata import AnnData
+
 
 def run_diffmap(adata: AnnData, n_comps: int = 15, copy: bool = False):
     """\
@@ -37,9 +34,11 @@ def run_diffmap(adata: AnnData, n_comps: int = 15, copy: bool = False):
         Eigenvalues of transition matrix.
     """
 
-    scanpy.tl.diffmap(adata, n_comps=n_comps, copy=copy)
+    adata = scanpy.tl.diffmap(adata, n_comps=n_comps, copy=copy)
 
     print(
-        "Diffusion Map is done! Generated in adata.obsm['X_diffmap'] nad adata.uns['diffmap_evals']")
+        "Diffusion Map is done! Generated in adata.obsm['X_diffmap'] and "
+        + "adata.uns['diffmap_evals']"
+    )
 
-    return adata if copy else None
\ No newline at end of file
+    return adata
