@@ -1,13 +1,11 @@
-from typing import Optional, Union
+from typing import Literal
 
 import numpy as np
+import scanpy
 from anndata import AnnData
 from numpy.random.mtrand import RandomState
 
-from .._compat import Literal
-import scanpy
-
-_InitPos = Literal['paga', 'spectral', 'random']
+_InitPos = Literal["paga", "spectral", "random"]
 
 
 def run_umap(
@@ -15,18 +13,17 @@ def run_umap(
     min_dist: float = 0.5,
     spread: float = 1.0,
     n_components: int = 2,
-
-    maxiter: Optional[int] = None,
+    maxiter: int | None = None,
     alpha: float = 1.0,
     gamma: float = 1.0,
     negative_sample_rate: int = 5,
-    init_pos: Union[_InitPos, np.ndarray, None] = 'spectral',
-    random_state: Optional[Union[int, RandomState]] = 0,
-    a: Optional[float] = None,
-    b: Optional[float] = None,
+    init_pos: _InitPos | np.ndarray | None = "spectral",
+    random_state: int | RandomState | None = 0,
+    a: float | None = None,
+    b: float | None = None,
     copy: bool = False,
-    method: Literal['umap', 'rapids'] = 'umap'
-) -> Optional[AnnData]:
+    method: Literal["umap", "rapids"] = "umap",  # noqa: F821
+) -> AnnData | None:
     """\
     Wrap function scanpy.pp.umap
     Embed the neighborhood graph using UMAP [McInnes18]_.
@@ -59,9 +56,23 @@ def run_umap(
 
     """
 
-    scanpy.tl.umap(adata, min_dist=min_dist, spread=spread, n_components=n_components,
-         maxiter=maxiter, alpha=alpha, gamma=gamma, negative_sample_rate=negative_sample_rate,
-         init_pos=init_pos, random_state=random_state, a=a, b=b, copy=copy, method=method)
+    adata = scanpy.tl.umap(
+        adata,
+        min_dist=min_dist,
+        spread=spread,
+        n_components=n_components,
+        maxiter=maxiter,
+        alpha=alpha,
+        gamma=gamma,
+        negative_sample_rate=negative_sample_rate,
+        init_pos=init_pos,
+        random_state=random_state,
+        a=a,
+        b=b,
+        copy=copy,
+        method=method,
+    )
 
-    print(
-        "UMAP is done! Generated in adata.obsm['X_umap'] nad adata.uns['umap']")
+    print("UMAP is done! Generated in adata.obsm['X_umap'] nad adata.uns['umap']")
+
+    return adata
