@@ -1,23 +1,17 @@
-def encode(tiles, model):
-    features = model.predict(tiles)
-    features = features.ravel()
-    return features
-
-
 class Model:
     __name__ = "CNN base model"
 
     def __init__(self, base, batch_size=1):
-        from tensorflow.keras import backend as K
+        from keras import backend as keras
 
         self.base = base
         self.model, self.preprocess = self.load_model()
         self.batch_size = batch_size
-        self.data_format = K.image_data_format()
+        self.data_format = keras.image_data_format()
 
     def load_model(self):
         if self.base == "resnet50":
-            from tensorflow.keras.applications.resnet50 import (
+            from keras.applications.resnet50 import (
                 ResNet50,
                 preprocess_input,
             )
@@ -26,11 +20,11 @@ class Model:
                 include_top=False, weights="imagenet", pooling="avg"
             )
         elif self.base == "vgg16":
-            from tensorflow.keras.applications.vgg16 import VGG16, preprocess_input
+            from keras.applications.vgg16 import VGG16, preprocess_input
 
             cnn_base_model = VGG16(include_top=False, weights="imagenet", pooling="avg")
         elif self.base == "inception_v3":
-            from tensorflow.keras.applications.inception_v3 import (
+            from keras.applications.inception_v3 import (
                 InceptionV3,
                 preprocess_input,
             )
@@ -39,7 +33,7 @@ class Model:
                 include_top=False, weights="imagenet", pooling="avg"
             )
         elif self.base == "xception":
-            from tensorflow.keras.applications.xception import (
+            from keras.applications.xception import (
                 Xception,
                 preprocess_input,
             )
@@ -48,13 +42,13 @@ class Model:
                 include_top=False, weights="imagenet", pooling="avg"
             )
         else:
-            raise ValueError("{} is not a valid model".format(self.base))
+            raise ValueError(f"{self.base} is not a valid model")
         return cnn_base_model, preprocess_input
 
     def predict(self, x):
-        from tensorflow.keras import backend as K
+        from keras import backend as keras
 
         if self.data_format == "channels_first":
             x = x.transpose(0, 3, 1, 2)
-        x = self.preprocess(x.astype(K.floatx()))
+        x = self.preprocess(x.astype(keras.floatx()))
         return self.model.predict(x, batch_size=self.batch_size, verbose=False)
