@@ -1,56 +1,57 @@
-"""Reading and Writing
-"""
-from pathlib import Path, PurePath
-from typing import Optional, Union
-from anndata import AnnData
-import numpy as np
-from PIL import Image
-import pandas as pd
-import stlearn
-from .._compat import Literal
-import scanpy
-import scipy
-import matplotlib.pyplot as plt
+"""Reading and Writing"""
 
-_QUALITY = Literal["fulres", "hires", "lowres"]
-_background = ["black", "white"]
+import json
+import logging as logg
+from collections.abc import Iterator
+from os import PathLike
+from pathlib import Path
+
+import matplotlib.pyplot as plt
+import numpy as np
+import pandas as pd
+import scanpy
+from anndata import AnnData
+from matplotlib.image import imread
+from PIL import Image
+
+import stlearn
+from stlearn.types import _BACKGROUND, _QUALITY
+from stlearn.wrapper.xenium_alignment import apply_alignment_transformation
 
 
 def Read10X(
-    path: Union[str, Path],
-    genome: Optional[str] = None,
+    path: str | Path,
+    genome: str | None = None,
     count_file: str = "filtered_feature_bc_matrix.h5",
-    library_id: str = None,
-    load_images: Optional[bool] = True,
+    library_id: str | None = None,
+    load_images: bool = True,
     quality: _QUALITY = "hires",
-    image_path: Union[str, Path] = None,
+    image_path: str | Path | None = None,
 ) -> AnnData:
-
     """\
-    Read Visium data from 10X (wrap read_visium from scanpy)
+    Read data from 10X.
 
-    In addition to reading regular 10x output,
-    this looks for the `spatial` folder and loads images,
-    coordinates and scale factors.
-    Based on the `Space Ranger output docs`_.
-
-    .. _Space Ranger output docs: https://support.10xgenomics.com/spatial-gene-expression/software/pipelines/latest/output/overview
+    In addition to reading regular 10x output, this looks for the `spatial` folder
+    and loads images, coordinates and scale factors. Based on the
+    https://support.10xgenomics.com/spatial-gene-expression/software/pipelines/latest/output/overview
 
     Parameters
     ----------
     path
-        Path to directory for visium datafiles.
+        The path to directory for the datafiles.
     genome
         Filter expression to genes within this genome.
     count_file
-        Which file in the passed directory to use as the count file. Typically would be one of:
-        'filtered_feature_bc_matrix.h5' or 'raw_feature_bc_matrix.h5'.
+        Which file in the directory to use as the count file. Typically, it would be one
+        of: 'filtered_feature_bc_matrix.h5' or 'raw_feature_bc_matrix.h5'.
     library_id
-        Identifier for the visium library. Can be modified when concatenating multiple adata objects.
+        Identifier for the library. Can be modified when concatenating multiple
+        adata objects.
     load_images
         Load image or not.
     quality
-        Set quality that convert to stlearn to use. Store in anndata.obs['imagecol' & 'imagerow']
+        Set quality that convert to stlearn to use. Store in
+        anndata.obs['imagecol' & 'imagerow']
     image_path
         Path to image. Only need when loading full resolution image.
 
@@ -81,47 +82,130 @@ def Read10X(
         Spatial spot coordinates, usable as `basis` by :func:`~scanpy.pl.embedding`.
     """
 
-    from scanpy import read_visium
+    path = Path(path)
+    adata = scanpy.read_10x_h5(path / count_file, genome=genome)
 
-    adata = read_visium(
-        path,
-        genome=genome,
-        count_file=count_file,
-        library_id=library_id,
-        load_images=load_images,
-    )
-    adata.var_names_make_unique()
+    adata.uns["spatial"] = dict()
+
+    from h5py import File
+
+    with File(path / count_file, mode="r") as f:
+        attrs = dict(f.attrs)
 
     if library_id is None:
-        library_id = list(adata.uns["spatial"].keys())[0]
+        library_id = str(attrs.pop("library_ids")[0], "utf-8")
+    adata.uns["spatial"][library_id] = dict()
 
-    if quality == "fulres":
-        image_coor = adata.obsm["spatial"]
-        img = plt.imread(image_path, 0)
-        adata.uns["spatial"][library_id]["images"]["fulres"] = img
-    else:
-        scale = adata.uns["spatial"][library_id]["scalefactors"][
-            "tissue_" + quality + "_scalef"
+    tissue_positions_file = (
+        path / "spatial/tissue_positions.csv"
+        if (path / "spatial/tissue_positions.csv").exists()
+        else path / "spatial/tissue_positions_list.csv"
+    )
+
+    if load_images:
+        files = dict(
+            tissue_positions_file=tissue_positions_file,
+            scalefactors_json_file=path / "spatial/scalefactors_json.json",
+            hires_image=path / "spatial/tissue_hires_image.png",
+            lowres_image=path / "spatial/tissue_lowres_image.png",
+        )
+
+        # check if files exists, continue if images are missing
+        for f in files.values():
+            if not f.exists():
+                if any(x in str(f) for x in ["hires_image", "lowres_image"]):
+                    logg.warning(
+                        f"You seem to be missing an image file.\nCould not find '{f}'."
+                    )
+                else:
+                    raise OSError(f"Could not find '{f}'")
+
+        adata.uns["spatial"][library_id]["images"] = dict()
+        for res in ["hires", "lowres"]:
+            try:
+                adata.uns["spatial"][library_id]["images"][res] = imread(
+                    str(files[f"{res}_image"])
+                )
+            except Exception:
+                raise OSError(f"Could not find '{res}_image'")
+
+        # read json scalefactors
+        adata.uns["spatial"][library_id]["scalefactors"] = json.loads(
+            files["scalefactors_json_file"].read_bytes()
+        )
+
+        adata.uns["spatial"][library_id]["metadata"] = {
+            k: (str(attrs[k], "utf-8") if isinstance(attrs[k], bytes) else attrs[k])
+            for k in ("chemistry_description", "software_version")
+            if k in attrs
+        }
+
+        # read coordinates
+        positions = pd.read_csv(files["tissue_positions_file"], header=None)
+        positions.columns = [
+            "barcode",
+            "in_tissue",
+            "array_row",
+            "array_col",
+            "pxl_col_in_fullres",
+            "pxl_row_in_fullres",
         ]
-        image_coor = adata.obsm["spatial"] * scale
+        positions.index = positions["barcode"]
 
-    adata.obs["imagecol"] = image_coor[:, 0]
-    adata.obs["imagerow"] = image_coor[:, 1]
-    adata.uns["spatial"][library_id]["use_quality"] = quality
+        adata.obs = adata.obs.join(positions, how="left")
+
+        adata.obsm["spatial"] = (
+            adata.obs[["pxl_row_in_fullres", "pxl_col_in_fullres"]]
+            .to_numpy()
+            .astype(float)
+        )
+        adata.obs.drop(
+            columns=["barcode", "pxl_row_in_fullres", "pxl_col_in_fullres"],
+            inplace=True,
+        )
+
+        if quality == "fulres":
+            # put image path in uns
+            if image_path is not None:
+                # get an absolute path
+                image_path = str(Path(image_path).resolve())
+                adata.uns["spatial"][library_id]["metadata"]["source_image_path"] = str(
+                    image_path
+                )
+            else:
+                raise ValueError("Trying to load fulres but no image_path set.")
+
+            image_coor = adata.obsm["spatial"]
+            img = plt.imread(image_path, None)
+            adata.uns["spatial"][library_id]["images"]["fulres"] = img
+        else:
+            scale = adata.uns["spatial"][library_id]["scalefactors"][
+                "tissue_" + quality + "_scalef"
+            ]
+            image_coor = adata.obsm["spatial"] * scale
+
+        adata.obs["imagecol"] = image_coor[:, 0]
+        adata.obs["imagerow"] = image_coor[:, 1]
+        adata.uns["spatial"][library_id]["use_quality"] = quality
+
+    adata.var_names_make_unique()
+
+    adata.obs["array_row"] = adata.obs["array_row"].astype(int)
+    adata.obs["array_col"] = adata.obs["array_col"].astype(int)
+    adata.obsm["spatial"] = adata.obsm["spatial"].astype("int64")
 
     return adata
 
 
 def ReadOldST(
-    count_matrix_file: Union[str, Path] = None,
-    spatial_file: Union[str, Path] = None,
-    image_file: Union[str, Path] = None,
+    count_matrix_file: PathLike[str] | str | Iterator[str],
+    spatial_file: int | str | bytes | PathLike[str] | PathLike[bytes],
+    image_file: str | Path | None = None,
     library_id: str = "OldST",
     scale: float = 1.0,
     quality: str = "hires",
     spot_diameter_fullres: float = 50,
 ) -> AnnData:
-
     """\
     Read Old Spatial Transcriptomics data
 
@@ -130,15 +214,17 @@ def ReadOldST(
     count_matrix_file
         Path to count matrix file.
     spatial_file
-        Path to spatial location file.
+        Path to the spatial location file.
     image_file
         Path to the tissue image file
     library_id
-        Identifier for the visium library. Can be modified when concatenating multiple adata objects.
+        Identifier for the library. Can be modified when concatenating multiple
+        adata objects.
     scale
         Set scale factor.
     quality
-        Set quality that convert to stlearn to use. Store in anndata.obs['imagecol' & 'imagerow']
+        Set quality that convert to stlearn to use. Store in
+        anndata.obs['imagecol' & 'imagerow']
     spot_diameter_fullres
         Diameter of spot in full resolution
 
@@ -162,15 +248,14 @@ def ReadOldST(
 
 
 def ReadSlideSeq(
-    count_matrix_file: Union[str, Path],
-    spatial_file: Union[str, Path],
-    library_id: str = None,
-    scale: float = None,
+    count_matrix_file: str | Path,
+    spatial_file: str | Path,
+    library_id: str | None = None,
+    scale: float | None = None,
     quality: str = "hires",
     spot_diameter_fullres: float = 50,
-    background_color: _background = "white",
+    background_color: _BACKGROUND = "white",
 ) -> AnnData:
-
     """\
     Read Slide-seq data
 
@@ -179,17 +264,19 @@ def ReadSlideSeq(
     count_matrix_file
         Path to count matrix file.
     spatial_file
-        Path to spatial location file.
+        Path to the spatial location file.
     library_id
-        Identifier for the visium library. Can be modified when concatenating multiple adata objects.
+        Identifier for the library. Can be modified when concatenating
+        multiple adata objects.
     scale
         Set scale factor.
     quality
-        Set quality that convert to stlearn to use. Store in anndata.obs['imagecol' & 'imagerow']
+        Set quality that convert to stlearn to use. Store in
+        anndata.obs['imagecol' & 'imagerow']
     spot_diameter_fullres
         Diameter of spot in full resolution
     background_color
-        Color of the backgound. Only `black` or `white` is allowed.
+        Color of the background. Only `black` or `white` is allowed.
 
     Returns
     -------
@@ -205,7 +292,7 @@ def ReadSlideSeq(
 
     adata.obs["index"] = meta["index"].values
 
-    if scale == None:
+    if scale is None:
         max_coor = np.max(meta[["x", "y"]].values)
         scale = 2000 / max_coor
 
@@ -244,15 +331,14 @@ def ReadSlideSeq(
 
 
 def ReadMERFISH(
-    count_matrix_file: Union[str, Path],
-    spatial_file: Union[str, Path],
-    library_id: str = None,
-    scale: float = None,
+    count_matrix_file: str | Path,
+    spatial_file: str | Path,
+    library_id: str | None = None,
+    scale: float | None = None,
     quality: str = "hires",
     spot_diameter_fullres: float = 50,
-    background_color: _background = "white",
+    background_color: _BACKGROUND = "white",
 ) -> AnnData:
-
     """\
     Read MERFISH data
 
@@ -261,17 +347,19 @@ def ReadMERFISH(
     count_matrix_file
         Path to count matrix file.
     spatial_file
-        Path to spatial location file.
+        Path to the spatial location file.
     library_id
-        Identifier for the visium library. Can be modified when concatenating multiple adata objects.
+        Identifier for the library. Can be modified when concatenating
+        multiple adata objects.
     scale
         Set scale factor.
     quality
-        Set quality that convert to stlearn to use. Store in anndata.obs['imagecol' & 'imagerow']
+        Set quality that convert to stlearn to use. Store in
+        anndata.obs['imagecol' & 'imagerow']
     spot_diameter_fullres
         Diameter of spot in full resolution
     background_color
-        Color of the backgound. Only `black` or `white` is allowed.
+        Color of the background. Only `black` or `white` is allowed.
 
     Returns
     -------
@@ -288,7 +376,7 @@ def ReadMERFISH(
     adata_merfish = counts[coordinates.index, :]
     adata_merfish.obsm["spatial"] = coordinates.to_numpy()
 
-    if scale == None:
+    if scale is None:
         max_coor = np.max(adata_merfish.obsm["spatial"])
         scale = 2000 / max_coor
 
@@ -326,16 +414,15 @@ def ReadMERFISH(
 
 
 def ReadSeqFish(
-    count_matrix_file: Union[str, Path],
-    spatial_file: Union[str, Path],
-    library_id: str = None,
+    count_matrix_file: str | Path,
+    spatial_file: str | Path,
+    library_id: str | None = None,
     scale: float = 1.0,
     quality: str = "hires",
     field: int = 0,
     spot_diameter_fullres: float = 50,
-    background_color: _background = "white",
+    background_color: _BACKGROUND = "white",
 ) -> AnnData:
-
     """\
     Read SeqFish data
 
@@ -346,17 +433,19 @@ def ReadSeqFish(
     spatial_file
         Path to spatial location file.
     library_id
-        Identifier for the visium library. Can be modified when concatenating multiple adata objects.
+        Identifier for the library. Can be modified when concatenating multiple
+        adata objects.
     scale
         Set scale factor.
     quality
-        Set quality that convert to stlearn to use. Store in anndata.obs['imagecol' & 'imagerow']
+        Set quality that convert to stlearn to use. Store in
+        anndata.obs['imagecol' & 'imagerow']
     field
         Set field of view for SeqFish data
     spot_diameter_fullres
         Diameter of spot in full resolution
     background_color
-        Color of the backgound. Only `black` or `white` is allowed.
+        Color of the background. Only `black` or `white` is allowed.
     Returns
     -------
     AnnData
@@ -374,7 +463,7 @@ def ReadSeqFish(
 
     adata = AnnData(count)
 
-    if scale == None:
+    if scale is None:
         max_coor = np.max(spatial[["X", "Y"]])
         scale = 2000 / max_coor
 
@@ -413,16 +502,18 @@ def ReadSeqFish(
 
 
 def ReadXenium(
-    feature_cell_matrix_file: Union[str, Path],
-    cell_summary_file: Union[str, Path],
-    image_path: Optional[Path] = None,
-    library_id: str = None,
+    feature_cell_matrix_file: str | Path,
+    cell_summary_file: str | Path,
+    image_path: Path | None = None,
+    library_id: str | None = None,
     scale: float = 1.0,
     quality: str = "hires",
     spot_diameter_fullres: float = 15,
-    background_color: _background = "white",
+    background_color: _BACKGROUND = "white",
+    alignment_matrix_file: str | Path | None = None,
+    experiment_xenium_file: str | Path | None = None,
+    default_pixel_size_microns: float = 0.2125,
 ) -> AnnData:
-
     """\
     Read Xenium data
 
@@ -435,15 +526,25 @@ def ReadXenium(
     image_path
         Path to image. Only need when loading full resolution image.
     library_id
-        Identifier for the visium library. Can be modified when concatenating multiple adata objects.
+        Identifier for the Xenium library. Can be modified when concatenating multiple
+        adata objects.
     scale
         Set scale factor.
     quality
-        Set quality that convert to stlearn to use. Store in anndata.obs['imagecol' & 'imagerow']
+        Set quality that convert to stlearn to use. Store in
+        anndata.obs['imagecol' & 'imagerow']
     spot_diameter_fullres
         Diameter of spot in full resolution
     background_color
-        Color of the backgound. Only `black` or `white` is allowed.
+        Color of the background. Only `black` or `white` is allowed.
+    alignment_matrix_file
+        Path to transformation matrix CSV file exported from Xenium Explorer.
+        If provided, coordinates will be transformed according to coordinate_space.
+    experiment_xenium_file
+        Path to experiment.xenium JSON file. If provided, pixel_size will be read from
+        here.
+    default_pixel_size_microns
+        Pixel size in microns (default 0.2125 for Xenium data).
     Returns
     -------
     AnnData
@@ -453,12 +554,34 @@ def ReadXenium(
 
     adata = scanpy.read_10x_h5(feature_cell_matrix_file)
 
-    spatial = metadata[["x_centroid", "y_centroid"]]
-    spatial.columns = ["imagecol", "imagerow"]
+    # Get original spatial coordinates
+    spatial = metadata[["x_centroid", "y_centroid"]].copy()
 
+    # Get pixel size from experiment.xenium file or use parameter
+    if experiment_xenium_file is not None:
+        with open(experiment_xenium_file) as f:
+            experiment_data = json.load(f)
+        pixel_size_microns = experiment_data.get("pixel_size")
+    else:
+        pixel_size_microns = default_pixel_size_microns
+        print(
+            f"Warning: Using default pixel size of {pixel_size_microns} microns. "
+            "Consider providing experiment_xenium_file for accurate pixel size."
+        )
+
+    # Get and apply alignment transformation if provided
+    if alignment_matrix_file is not None:
+        transform_mat = pd.read_csv(alignment_matrix_file, header=None).values
+        spatial = apply_alignment_transformation(
+            spatial,
+            transform_mat,
+            pixel_size_microns,
+        )
+
+    spatial.columns = ["imagecol", "imagerow"]
     adata.obsm["spatial"] = spatial.values
 
-    if scale == None:
+    if scale is None:
         max_coor = np.max(adata.obsm["spatial"])
         scale = 2000 / max_coor
 
@@ -468,7 +591,7 @@ def ReadXenium(
     adata.obs["imagecol"] = spatial["imagecol"].values * scale
     adata.obs["imagerow"] = spatial["imagerow"].values * scale
 
-    if image_path != None:
+    if image_path is not None:
         stlearn.add.image(
             adata,
             library_id=library_id,
@@ -508,11 +631,11 @@ def create_stlearn(
     count: pd.DataFrame,
     spatial: pd.DataFrame,
     library_id: str,
-    image_path: Optional[Path] = None,
-    scale: float = None,
+    image_path: Path | None = None,
+    scale: float | None = None,
     quality: str = "hires",
     spot_diameter_fullres: float = 50,
-    background_color: _background = "white",
+    background_color: _BACKGROUND = "white",
 ):
     """\
     Create AnnData object for stLearn
@@ -524,15 +647,17 @@ def create_stlearn(
     spatial
         Pandas Dataframe of spatial location of cells/spots.
     library_id
-        Identifier for the visium library. Can be modified when concatenating multiple adata objects.
+        Identifier for the library. Can be modified when concatenating multiple
+        adata objects.
     scale
         Set scale factor.
     quality
-        Set quality that convert to stlearn to use. Store in anndata.obs['imagecol' & 'imagerow']
+        Set quality that convert to stlearn to use. Store in
+        anndata.obs['imagecol' & 'imagerow']
     spot_diameter_fullres
         Diameter of spot in full resolution
     background_color
-        Color of the backgound. Only `black` or `white` is allowed.
+        Color of the background. Only `black` or `white` is allowed.
     Returns
     -------
     AnnData
@@ -541,14 +666,14 @@ def create_stlearn(
 
     adata.obsm["spatial"] = spatial.values
 
-    if scale == None:
+    if scale is None:
         max_coor = np.max(adata.obsm["spatial"])
         scale = 2000 / max_coor
 
     adata.obs["imagecol"] = spatial["imagecol"].values * scale
     adata.obs["imagerow"] = spatial["imagerow"].values * scale
 
-    if image_path != None:
+    if image_path is not None:
         stlearn.add.image(
             adata,
             library_id=library_id,
